@@ -1,6 +1,15 @@
 from dataclasses import dataclass, field
+from glob import glob
 from typing import Optional, Dict, Any
 from graphql.language import OperationDefinitionNode, parse
+from graphql import (
+    DocumentNode,
+    GraphQLSchema,
+    get_introspection_query,
+    get_operation_ast,
+    parse,
+    build_ast_schema,
+)
 
 
 @dataclass
@@ -18,6 +27,7 @@ class Extensions:
 
 @dataclass
 class Operation:
+    document_node: DocumentNode
     node: OperationDefinitionNode
     document: str
     variables: Dict[str, Any]
@@ -39,17 +49,18 @@ def opify(
     query: str,
     variables: Dict[str, Any] = None,
     headers: Dict[str, Any] = {},
-    operation_name: str = None,
+    operation_name: Optional[str] = None,
     **kwargs,
 ) -> Operation:
 
     document = parse(query)
-
-    op = [o for o in document.definitions if isinstance(o, OperationDefinitionNode)][0]
-
+    print(operation_name)
+    op = get_operation_ast(document, operation_name)
+    assert op, f"No operation named {operation_name}"
     return Operation(
         node=op,
         document=query,
+        document_node=document,
         variables=variables or {},
         operation_name=operation_name,
         extensions={},
